@@ -1,5 +1,5 @@
 -- hkt.hs: hOpenPGP key tool
--- Copyright © 2013-2016  Clint Adams
+-- Copyright © 2013-2017  Clint Adams
 --
 -- vim: softtabstop=4:shiftwidth=4:expandtab
 --
@@ -339,7 +339,7 @@ doFindPaths o = do
         ttarget3 = T.pack . target3
     cpt <- getPOSIXTime
     kr <- grabMatchingKeysKeyring (keyring o) (targetIsFilter o) (ttarget1 o)
-    -- FIXME: clean this up
+    -- FIXME: seriously clean this up
     keys1 <- runResourceT $ CL.sourceList (IxSet.toList kr) $= (if filt then conduitTKFilter (ufpt (ttarget2 o)) else CL.filter (matchAny (ttarget2 o))) $$ CL.consume
     keys2 <- runResourceT $ CL.sourceList (IxSet.toList kr) $= (if filt then conduitTKFilter (ufpt (ttarget3 o)) else CL.filter (matchAny (ttarget3 o))) $$ CL.consume
     let ((KeyMaps k2f f2i i2f, i), ks) = (buildMaps &&& id) (rights (map (verifyTKWith (verifySigWith (verifyAgainstKeyring kr)) (Just (posixSecondsToUTCTime cpt))) (IxSet.toList kr)))
@@ -348,7 +348,7 @@ doFindPaths o = do
         froms = keysToIs keys1
         tos = keysToIs keys2
         combos = froms >>= \f -> tos >>= \t -> return (f,t)
-        paths = map (\(x,y) -> sp x y (emap (const (1.0 :: Double)) keygraph)) combos
+        paths = map (\(x,y) -> fromMaybe [] (sp x y (emap (const (1.0 :: Double)) keygraph))) combos
         paf = PaF paths (Map.fromList (mapMaybe (\x -> HashMap.lookup x i2f >>= \y -> return (show x,y)) (nub (sort (concat paths)))))
     case pathsOutputFormat o of
         Unstructured -> do -- FIXME: do something about this
