@@ -1,5 +1,5 @@
 -- hokey.hs: hOpenPGP key tool
--- Copyright © 2013-2016  Clint Adams
+-- Copyright © 2013-2018  Clint Adams
 --
 -- vim: softtabstop=4:shiftwidth=4:expandtab
 --
@@ -118,7 +118,7 @@ data UIDReport = UIDReport {
 } deriving Generic
 
 data SubkeyReport = SubkeyReport {
-    skFingerprint :: TwentyOctetFingerprint
+    skFingerprint :: Colored TwentyOctetFingerprint
   , skVer :: Colored KeyVersion
   , skCreationTime :: ThirtyTwoBitTimeStamp
   , skAlgorithmAndSize :: KAS
@@ -162,7 +162,7 @@ checkKey mpt key = (\x -> x { keyBestOf = populateBestOf x, keyHasEncryptionCapa
   , keyAlgorithmAndSize = kasIt (key^.tkKey._1)
   , keyUIDsAndUAts = FakeMap (map (\(x,y) -> (x, uidr (Just x) y)) (processedOrOrig^.tkUIDs) ++ map (uatspsToText *** uidr Nothing) (processedOrOrig^.tkUAts))
   , keyBestOf = Nothing
-  , keySubkeys = map checkSK (key^.tkSubs)
+  , keySubkeys = map (checkSK (key^.tkKey._1 & fingerprint)) (key^.tkSubs)
   , keyHasEncryptionCapableSubkey = Colored Nothing Nothing False
 }
     where
@@ -236,11 +236,11 @@ checkKey mpt key = (\x -> x { keyBestOf = populateBestOf x, keyHasEncryptionCapa
         newestWith p = take 1 . sortBy (comparing (Down . take 1 . sigcts)) . filter p -- FIXME: this is terrible
         hasheds (SigV4 _ _ _ xs _ _ _) = xs
         hasheds _ = []
-        checkSK :: (Pkt, [SignaturePayload]) -> SubkeyReport
-        checkSK (PublicSubkeyPkt pkp, sigs) = checkSK' pkp sigs
-        checkSK (SecretSubkeyPkt pkp _, sigs) = checkSK' pkp sigs
-        checkSK' pkp sigs = (\x -> x { skCrossCerts = ccr (map decolorize (skUsageFlags x)) sigs }) SubkeyReport {
-          skFingerprint = fingerprint pkp
+        checkSK :: TwentyOctetFingerprint -> (Pkt, [SignaturePayload]) -> SubkeyReport
+        checkSK pf (PublicSubkeyPkt pkp, sigs) = checkSK' pf pkp sigs
+        checkSK pf (SecretSubkeyPkt pkp _, sigs) = checkSK' pf pkp sigs
+        checkSK' pf pkp sigs = (\x -> x { skCrossCerts = ccr (map decolorize (skUsageFlags x)) sigs }) SubkeyReport {
+          skFingerprint = colorizeF pf (fingerprint pkp)
         , skVer = colorizeKV (pkp^.keyVersion)
         , skCreationTime = pkp^.timestamp
         , skAlgorithmAndSize = kasIt pkp
@@ -264,6 +264,7 @@ checkKey mpt key = (\x -> x { keyBestOf = populateBestOf x, keyHasEncryptionCapa
                                 (False, False, True) -> Colored (Just Green) Nothing True
                                 (False, False, False) -> Colored Nothing Nothing True
                                 (True, _, _) -> Colored Nothing Nothing False
+        colorizeF pf fp = uncurry Colored (if pf == fp then (Just Red, Just "subkey has same fingerprint as primary key") else (Just Green, Nothing)) fp
 
 prettyKeyReport :: POSIXTime -> TK -> Doc Effect
 prettyKeyReport cpt key = do
@@ -296,7 +297,7 @@ prettyKeyReport cpt key = do
           <> linebreak <> indent 4 (text "Revocation reason" <> colon <+> list (map (text . T.unpack . revocationReason) (uidRevocationStatus ur)))
         keyExp ts ke = (show . pretty) ke ++ " = " ++ formatTime defaultTimeLocale "%c" (posixSecondsToUTCTime (realToFrac ts + realToFrac ke))
         gottabeabetterway (a, Colored x y z) = (Colored x y a, z)
-        subkeyrep skr = linebreak <> indent 2 (text "fpr" <> colon <+> pretty (SpacedFingerprint (skFingerprint skr)))
+        subkeyrep skr = linebreak <> indent 2 (text "fpr" <> colon <+> coloredToColor pretty (fmap SpacedFingerprint (skFingerprint skr)))
                      <> linebreak <> indent 4 (text "version" <> colon <+> coloredToColor pretty (skVer skr))
                      <> linebreak <> indent 4 (text "timestamp" <> colon <+> pretty (skCreationTime skr))
                      <> linebreak <> indent 4 ((\kas -> text "algo/size" <> colon <+> coloredToColor pretty (pubkeyalgo kas) <+> coloredToColor (maybe (text "unknown") pretty) (pubkeysize kas)) (skAlgorithmAndSize skr))
