@@ -28,7 +28,7 @@ import Codec.Encryption.OpenPGP.ASCIIArmor.Types (Armor(..), ArmorType(..))
 import Codec.Encryption.OpenPGP.Serialize ()
 import Codec.Encryption.OpenPGP.Types
 #if !MIN_VERSION_base(4,8,0)
-import Control.Applicative ((<$>), (<*>))
+import Control.Applicative ((<$>), (<*>), pure)
 #endif
 import Control.Applicative (optional)
 import Control.Error.Util (note)
@@ -54,7 +54,7 @@ import Options.Applicative.Builder (argument, command, footerDoc, headerDoc, hel
 import Options.Applicative.Extra (customExecParser, helper, hsubparser)
 import Options.Applicative.Types (Parser)
 import qualified Text.PrettyPrint.ANSI.Leijen as PPAL
-import Text.PrettyPrint.Free (Pretty, pretty)
+import Text.PrettyPrint.Free (group, hardline, hPutDoc, Pretty, pretty)
 
 data Command = DumpC DumpOptions | DeArmorC | ArmorC ArmoringOptions | FilterC FilteringOptions
 
@@ -86,7 +86,7 @@ printer :: (Show a, MonadIO m) => Sink a m ()
 printer = CL.mapM_ (liftIO . print)
 
 prettyPrinter :: (Pretty a, MonadIO m) => Sink a m ()
-prettyPrinter = CL.mapM_ (liftIO . putStrLn . show . pretty)
+prettyPrinter = CL.mapM_ (liftIO . hPutDoc stdout . (<> hardline) . group . pretty)
 
 jsonSink :: (A.ToJSON a, MonadIO m) => Sink a m ()
 jsonSink = CL.mapM_ (liftIO . BL.putStr . flip BL.snoc 0x0a . A.encode)
@@ -157,7 +157,7 @@ dispatch c = (banner' stderr >> hFlush stderr) >> dispatch' c
 main :: IO ()
 main = do
     hSetBuffering stderr LineBuffering
-    customExecParser (prefs showHelpOnError) (info (helper <*> versioner <*> cmd) (headerDoc (Just (banner "hot")) <> progDesc "hOpenPGP OpenPGP-message Tool" <> footerDoc (Just (warranty "hot")))) >>= dispatch
+    customExecParser (prefs showHelpOnError) (info (helper <*> versioner "hot" <*> cmd) (headerDoc (Just (banner "hot")) <> progDesc "hOpenPGP OpenPGP-message Tool" <> footerDoc (Just (warranty "hot")))) >>= dispatch
 
 cmd :: Parser Command
 cmd = hsubparser
